# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/wojt/ai/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/wojt/ai/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Wojt\\Ai\\": "packages/wojt/ai/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Wojt\Ai\Providers\AiServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Ai'  => Wojt\Ai\Facades\Ai::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Wojt\\AiTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Wojt\Ai\Providers\AiServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Wojt\Ai\Providers\AiServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Wojt\Ai\Providers\AiServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/ai/{modulename}

**User**

    http://path-to-route-folder/user/ai/{modulename}

**Public**

    http://path-to-route-folder/ais


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/ai/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/ai/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/ai/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/ai/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/ai/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/ai/{modulename}/{slug}
    METHOD: GET